@@ -1,11 +1,13 @@
 #!/usr/bin/env python
 """
 :mod:`libnmap.plugin.s3` -- S3 Backend Plugin
-===================================
+=============================================
 
 .. module:: libnmap.plugin.s3
+
 :platform: Linux
 :synopsis: a plugin is representation of a S3 backend using boto
+
 .. moduleauthor:: Ronald Bister
 .. moduleauthor:: Mike Boutillier
 """
@@ -86,8 +88,7 @@ class NmapS3Plugin(NmapBackendPlugin):
             strjsonnmapreport = json.dumps(report, cls=ReportEncoder)
             mykey.set_contents_from_string(strjsonnmapreport)
         except:
-            print "Bucket cannot insert"
-            raise
+            raise Exception("Failed to add nmap object in s3 bucket")
         return str(oid)
 
     def get(self, str_report_id=None):
@@ -106,7 +107,7 @@ class NmapS3Plugin(NmapBackendPlugin):
                 nmapreportjson = json.loads(mykey.get_contents_as_string())
                 nmapreport = NmapParser.parse_fromdict(nmapreportjson)
             except S3ResponseError:
-                print "Not Found"
+                pass
         return nmapreport
 
     def getall(self, dict_filter=None):
