@@ -53,15 +53,17 @@ class NmapSqlPlugin(NmapBackendPlugin):
 
         id = Column('report_id', Integer, primary_key=True)
         inserted = Column('inserted', DateTime(), default='now')
-        report_json = Column('report_json', LargeBinary)
+        report_json = Column('report_json', LargeBinary())
 
         def __init__(self, obj_NmapReport):
             self.inserted = datetime.fromtimestamp(obj_NmapReport.endtime)
-            self.report_json = json.dumps(obj_NmapReport,
-                                          cls=ReportEncoder)
+            dumped_json = json.dumps(obj_NmapReport,
+                                     cls=ReportEncoder)
+            self.report_json = bytes(dumped_json.encode('UTF-8'))
 
         def decode(self):
-            nmap_report_obj = json.loads(self.report_json,
+            json_decoded = self.report_json.decode('utf-8')
+            nmap_report_obj = json.loads(json_decoded,
                                          cls=ReportDecoder)
             return nmap_report_obj
 
@@ -103,8 +105,10 @@ class NmapSqlPlugin(NmapBackendPlugin):
     def insert(self, nmap_report):
         """
            insert NmapReport in the backend
+
            :param NmapReport:
-           :return: the ident of the object in the backend for future usage
+
+           :returns: the ident of the object in the backend for future usage \
            or None
         """
         sess = self.Session()
@@ -118,8 +122,10 @@ class NmapSqlPlugin(NmapBackendPlugin):
     def get(self, report_id=None):
         """
             retreive a NmapReport from the backend
+
             :param id: str
-            :return: NmapReport
+
+            :returns: NmapReport
         """
         if report_id is None:
             raise ValueError
@@ -131,8 +137,9 @@ class NmapSqlPlugin(NmapBackendPlugin):
 
     def getall(self):
         """
-            :return: collection of tuple (id,NmapReport)
             :param filter: Nice to have implement a filter capability
+
+            :returns: collection of tuple (id,NmapReport)
         """
         sess = self.Session()
         nmapreportList = []
@@ -146,8 +153,10 @@ class NmapSqlPlugin(NmapBackendPlugin):
     def delete(self, report_id=None):
         """
             Remove a report from the backend
+
             :param id: str
-            :return: The number of rows deleted
+
+            :returns: The number of rows deleted
         """
         if report_id is None:
             raise ValueError
