@@ -2,12 +2,16 @@
 # -*- coding: utf-8 -*-
 
 import os
-import pwd
 import shlex
 import subprocess
 from threading import Thread
 from xml.dom import pulldom
 import warnings
+import platform
+try:
+    import pwd
+except ImportError:
+    pass
 
 
 __all__ = [
@@ -84,6 +88,8 @@ class NmapProcess(Thread):
         unsafe_opts = set(['-oG', '-oN', '-iL', '-oA', '-oS', '-oX',
                            '--iflist', '--resume', '--stylesheet',
                            '--datadir'])
+        # more reliable than just using os.name() (cygwin)
+        self.__is_windows = platform.system() == 'Windows'
         if fqp:
             if os.path.isfile(fqp) and os.access(fqp, os.X_OK):
                 self.__nmap_binary = fqp
@@ -150,7 +156,9 @@ class NmapProcess(Thread):
 
         :todo: add a default path list in case PATH is empty.
         """
-        for path in os.environ.get('PATH', '').split(':'):
+        split_char = ';' if self.__is_windows else ':'
+        program = program + '.exe' if self.__is_windows else program
+        for path in os.environ.get('PATH', '').split(split_char):
             if (os.path.exists(os.path.join(path, program)) and not
                     os.path.isdir(os.path.join(path, program))):
                 return os.path.join(path, program)
@@ -245,12 +253,13 @@ class NmapProcess(Thread):
         return: return code from nmap execution
         """
         self._run_init()
-
-        _tmp_cmdline = shlex.split(self.__nmap_command_line)
+        _tmp_cmdline = self.__build_windows_cmdline() if self.__is_windows \
+            else shlex.split(self.__nmap_command_line)
         try:
             self.__nmap_proc = subprocess.Popen(args=_tmp_cmdline,
                                                 stdout=subprocess.PIPE,
                                                 stderr=subprocess.PIPE,
+                                                universal_newlines=True,
                                                 bufsize=0)
             self.__state = self.RUNNING
         except OSError:
@@ -260,12 +269,12 @@ class NmapProcess(Thread):
 
         while self.__nmap_proc.poll() is None:
             for streamline in iter(self.__nmap_proc.stdout.readline, ''):
-                self.__stdout += str(streamline)
+                self.__stdout += streamline
                 evnt = self.__process_event(streamline)
                 if self.__nmap_event_callback and evnt:
                     self.__nmap_event_callback(self)
 
-        self.__stderr += str(self.__nmap_proc.stderr.read().decode())
+        self.__stderr += self.__nmap_proc.stderr.read()
 
         self.__nmap_rc = self.__nmap_proc.poll()
         if self.rc is None:
@@ -405,6 +414,17 @@ class NmapProcess(Thread):
             pass
         return rval
 
+    def __build_windows_cmdline(self):
+        cmdline = []
+        cmdline.append(self.__nmap_binary)
+        if self.__nmap_fixed_options:
+            cmdline += self.__nmap_fixed_options.split()
+        if self.__nmap_dynamic_options:
+            cmdline += self.__nmap_dynamic_options.split()
+        if self.__nmap_targets:
+            cmdline += self.__nmap_targets  # already a list
+        return cmdline
+
     @property
     def command(self):
         """
